<?php
/**
Plugin Name: Google +1
Plugin URI: http://www.yatko.com/dev/widgets/wordpress/googleplusone/
Description: Google +1 WordPress plugin adds a configurable Google +1 Button to your WordPress blog. You can set the title, alignment, size and background of the +1 button. Simply install the plugin and place the widget. Visit http://www.yatko.com/dev/widgets/wordpress/googleplusone/
Version: 1.3.0
Author: Yatko
Author URI: http://www.yatko.com

 * The +1 Button Plugin is free software. This version may have been modified pursuant
 * to the GNU General Public License.
 * 
 * the +1 Button Plugin is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation.
 * 
 * +1 Button Plugin is distributed as is, without any warranty.
 * See the GNU General Public License for more details.
 * 
 * See <http://www.gnu.org/licenses/> for the GNU General Public License.


/**
 * Add function to widgets_init to load the widget.
 * @since 1.0.0
 */
add_action( 'widgets_init', 'plusone_load_widgets' );

/**
 * Register the plusone_Widget widget.
 * @since 1.0.0
 */
function plusone_load_widgets() {
	register_widget( 'plusone_Widget' );
}

/**
 * plusone Widget class, handles the settings, form, display, and update.
 * @since 1.0.0
 */
class plusone_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function plusone_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'plusone', 'description' => __('Google +1 WordPress widget adds a configurable Google +1 Button to your WordPress blog.', 'pusone') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'pusone-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'pusone-widget', __('Google +1 Widget', 'pusone'), $widget_ops, $control_ops );
	}

	/**
	 * Display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* The variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$plusoneAlign = $instance['plusone_Align'];
		$plusoneBGColor = $instance['plusone_BGColor'];
		$plusoneSize = $instance['plusone_Size'];
		$plusoneLanguage = $instance['plusone_Language'];

		/* Before widget (defined by themes). */
		echo $before_widget;

		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

?>

<script type="text/javascript" src="http://apis.google.com/js/plusone.js">
	{lang: '<?php echo $plusoneLanguage; ?>'}
</script>
<div style="text-align: <?php echo $plusoneAlign; ?>; background-color: <?php echo $plusoneBGColor; ?>;">
	<!-- Place this tag where you want the +1 button to render -->
	<g:plusone size="<?php echo $plusoneSize; ?>"></g:plusone>
</div>
<?php		

		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['plusone_Size'] = strip_tags( $new_instance['plusone_Size'] );
		$instance['plusone_Language'] = strip_tags( $new_instance['plusone_Language'] );
		$instance['plusone_Align'] = strip_tags( $new_instance['plusone_Align'] );
		$instance['plusone_BGColor'] = strip_tags( $new_instance['plusone_BGColor'] );

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 */
	function form( $instance ) {

		/* Set up default widget settings. */
		$defaults = array( 'title' => __('Google +1', 'plusone'), 'plusone_Size' => __('0', 'plusone'), 'plusone_Align' => __('center', 'plusone'), 'plusone_BGColor' => __('transparent', 'plusone'));
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'hybrid'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>

		<!-- plusone Size: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'plusone_Size' ); ?>"><?php _e('+1 Size:', 'standard'); ?></label>
			<select id="<?php echo $this->get_field_id( 'plusone_Size' ); ?>" name="<?php echo $this->get_field_name( 'plusone_Size' ); ?>" class="plusOneSelect" style="width:100%;">
				<option <?php if ( 'small' == $instance['plusone_Size'] ) echo 'selected="selected"'; ?>>small</option>
				<option <?php if ( 'medium' == $instance['plusone_Size'] ) echo 'selected="selected"'; ?>>medium</option>
				<option <?php if ( 'standard' == $instance['plusone_Size'] ) echo 'selected="selected"'; ?>>standard</option>
				<option <?php if ( 'tall' == $instance['plusone_Size'] ) echo 'selected="selected"'; ?>>tall</option>
			</select>
		</p>
		
		<!-- plusone Language: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'plusone_Language' ); ?>"><?php _e('+1 Language:', 'English'); ?></label>
			<select id="<?php echo $this->get_field_id( 'plusone_Language' ); ?>" name="<?php echo $this->get_field_name( 'plusone_Language' ); ?>" class="plusOneSelect" style="width:100%;">
				<option <?php if ( 'en-US' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>English</option>
				<option <?php if ( 'ar' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Arabic</option>
				<option <?php if ( 'bg' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Bulgarian</option>
				<option <?php if ( 'ca' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Catalan</option>
				<option <?php if ( 'zh-CN' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Chinese (Simplified)</option>
				<option <?php if ( 'zh-TW' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Chinese (Traditional)</option>
				<option <?php if ( 'hr' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Croatian</option>
				<option <?php if ( 'cs' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Czech</option>
				<option <?php if ( 'da' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Danish</option>
				<option <?php if ( 'nl' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Dutch</option>
				<option <?php if ( 'en-US' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>English (US)</option>
				<option <?php if ( 'en-GB' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>English (UK)</option>
				<option <?php if ( 'et' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Estonian</option>
				<option <?php if ( 'fil' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Filipino</option>
				<option <?php if ( 'fi' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Finnish</option>
				<option <?php if ( 'fr' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>French</option>
				<option <?php if ( 'de' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>German</option>
				<option <?php if ( 'el' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Greek</option>
				<option <?php if ( 'iw' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Hebrew</option>
				<option <?php if ( 'hi' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Hindi</option>
				<option <?php if ( 'hu' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Hungarian</option>
				<option <?php if ( 'id' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Indonesian</option>
				<option <?php if ( 'it' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Italian</option>
				<option <?php if ( 'ja' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Japanese</option>
				<option <?php if ( 'ko' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Korean</option>
				<option <?php if ( 'lv' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Latvian</option>
				<option <?php if ( 'lt' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Lithuanian</option>
				<option <?php if ( 'ms' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Malay</option>
				<option <?php if ( 'no' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Norwegian</option>
				<option <?php if ( 'fa' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Persian</option>
				<option <?php if ( 'pl' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Polish</option>
				<option <?php if ( 'pt-BR' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Portuguese (Brazil)</option>
				<option <?php if ( 'pt-PT' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Portuguese (Portugal)</option>
				<option <?php if ( 'ro' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Romanian</option>
				<option <?php if ( 'ru' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Russian</option>
				<option <?php if ( 'sr' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Serbian</option>
				<option <?php if ( 'sv' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Swedish</option>
				<option <?php if ( 'sk' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Slovak</option>
				<option <?php if ( 'sl' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Slovenian</option>
				<option <?php if ( 'es' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Spanish</option>
				<option <?php if ( 'es-419' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Spanish (Latin America)</option>
				<option <?php if ( 'th' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Thai</option>
				<option <?php if ( 'tr' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Turkish</option>
				<option <?php if ( 'uk' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Ukrainian</option>
				<option <?php if ( 'vi' == $instance['plusone_Language'] ) echo 'selected="selected"'; ?>>Vietnamese</option> 
			</select>
		</p>
		
		<!-- Align: Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'plusone_Align' ); ?>"><?php _e('Align:', 'center'); ?></label>
			<select id="<?php echo $this->get_field_id( 'plusone_Align' ); ?>" name="<?php echo $this->get_field_name( 'plusone_Align' ); ?>" class="plusOneSelect" style="width:100%;">
				<option <?php if ( 'center' == $instance['plusone_Align'] ) echo 'selected="selected"'; ?>>center</option>
				<option <?php if ( 'left' == $instance['plusone_Align'] ) echo 'selected="selected"'; ?>>left</option>
				<option <?php if ( 'right' == $instance['plusone_Align'] ) echo 'selected="selected"'; ?>>right</option>
			</select>
		</p>

		<!-- BG Color: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'plusone_BGColor' ); ?>"><?php _e('Background:', 'transparent'); ?></label> 
			<input id="<?php echo $this->get_field_id( 'plusone_BGColor' ); ?>" name="<?php echo $this->get_field_name( 'plusone_BGColor' ); ?>" value="<?php echo $instance['plusone_BGColor']; ?>" style="width:100%;" />
		</p>

	<?php
	}
}

?>